"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _List = _interopRequireDefault(require("./List"));
var _Box = _interopRequireDefault(require("./Box"));
var _SearchableBox = _interopRequireDefault(require("./SearchableBox"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const DEFAULT_HORIZONTAL_PADDING = 5;
const DEFAULT_ARROW_SIZE = 20;
const DEFAULT_PLACEHOLDER = 'Please select...';
const DEFAULT_SEARCH_PLACEHOLDER = 'Search here...';
const DEFAULT_HEIGHT = 40;
const DEFAULT_WIDTH = 250;
const DEFAULT_CLOSED_COLOR = '#6c757d';
const DEFAULT_OPENED_COLOR = '#000';
const DEFAULT_ARROW_COLOR_SELECTED = '#000';
const DEFAULT_ARROW_COLOR_UNSELECTED = '#6c757d';
const DEFAULT_BG_COLOR = '#fff';
const Base = /*#__PURE__*/(0, _react.memo)(props => {
  const {
    data,
    placeholder: mainPlaceHolder,
    width = DEFAULT_WIDTH,
    height = DEFAULT_HEIGHT,
    boxClosedBorderColor = DEFAULT_CLOSED_COLOR,
    boxOpenedBorderColor = DEFAULT_OPENED_COLOR,
    closeOnSelect = true,
    onSelect,
    placeHolderTextStyle = {},
    textStyle = {},
    arrowColorOnSelected = DEFAULT_ARROW_COLOR_SELECTED,
    arrowColor = DEFAULT_ARROW_COLOR_UNSELECTED,
    backgroundColor = DEFAULT_BG_COLOR,
    listBoxBackgroundColor,
    maxListHeight,
    listItemTextStyle,
    listItemSelectedTextStyle,
    listItemSelectedBackgroundColor,
    multiple = false,
    searchable = false,
    notFoundTextStyle = {},
    noDataText,
    defaultValues = []
  } = props;
  const placeholder = mainPlaceHolder || (searchable ? DEFAULT_SEARCH_PLACEHOLDER : DEFAULT_PLACEHOLDER);
  const [selected, setSelected] = (0, _react.useState)(defaultValues);
  const [opened, setOpened] = (0, _react.useState)(false);
  const [search, setSearch] = (0, _react.useState)('');
  const [locationConfig, setLocationConfig] = (0, _react.useState)({
    x: 0,
    y: 0
  });
  const ref = (0, _react.useRef)(null);
  const handleClick = () => {
    var _ref$current;
    ref === null || ref === void 0 ? void 0 : (_ref$current = ref.current) === null || _ref$current === void 0 ? void 0 : _ref$current.measureInWindow((x, y) => {
      setLocationConfig({
        x,
        y
      });
    });
    setOpened(prev => !prev);
  };
  const handleSelect = value => {
    if (multiple) {
      setSelected(prev => {
        let temp = prev;
        const found = temp.findIndex(item => item === value);
        if (found !== -1) {
          temp = temp.filter(item => item !== value);
        } else {
          temp.push(value);
        }
        return [...temp];
      });
    } else {
      setSelected([value]);
      if (closeOnSelect) {
        setOpened(false);
      }
    }
    setSearch('');
  };
  (0, _react.useEffect)(() => {
    if (typeof onSelect === 'function') {
      onSelect(selected);
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [selected]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    onPress: handleClick,
    ref: ref
  }, searchable ? /*#__PURE__*/_react.default.createElement(_SearchableBox.default, {
    data: data,
    placeholder: placeholder,
    width: width,
    height: height,
    boxClosedBorderColor: boxClosedBorderColor,
    boxOpenedBorderColor: boxOpenedBorderColor,
    placeHolderTextStyle: placeHolderTextStyle,
    textStyle: textStyle,
    arrowColorOnSelected: arrowColorOnSelected,
    arrowColor: arrowColor,
    backgroundColor: backgroundColor,
    arrowSize: DEFAULT_ARROW_SIZE,
    horizontalPadding: DEFAULT_HORIZONTAL_PADDING,
    opened: opened,
    selected: selected,
    handleChangeSearch: str => setSearch(str),
    search: search
  }) : /*#__PURE__*/_react.default.createElement(_Box.default, {
    data: data,
    placeholder: placeholder,
    width: width,
    height: height,
    boxClosedBorderColor: boxClosedBorderColor,
    boxOpenedBorderColor: boxOpenedBorderColor,
    placeHolderTextStyle: placeHolderTextStyle,
    textStyle: textStyle,
    arrowColorOnSelected: arrowColorOnSelected,
    arrowColor: arrowColor,
    backgroundColor: backgroundColor,
    arrowSize: DEFAULT_ARROW_SIZE,
    horizontalPadding: DEFAULT_HORIZONTAL_PADDING,
    opened: opened,
    selected: selected
  })), opened && /*#__PURE__*/_react.default.createElement(_List.default, {
    data: data,
    locationConfig: locationConfig,
    boxHeight: height,
    boxWidth: width,
    onSelect: handleSelect,
    selectedItemValues: selected,
    listBoxBackgroundColor: listBoxBackgroundColor,
    maxListHeight: maxListHeight,
    listItemTextStyle: listItemTextStyle,
    listItemSelectedTextStyle: listItemSelectedTextStyle,
    listItemSelectedBackgroundColor: listItemSelectedBackgroundColor,
    multiple: multiple,
    search: search,
    handleClose: () => setOpened(false),
    notFoundTextStyle: notFoundTextStyle,
    noDataText: noDataText
  }));
});
Base.displayName = 'Base';
var _default = Base;
exports.default = _default;
//# sourceMappingURL=base.js.map