import React, { memo, useEffect, useRef, useState } from 'react';
import { TouchableOpacity } from 'react-native';
import List from './List';
import ClickableBox from './Box';
import SearchableBox from './SearchableBox';
const DEFAULT_HORIZONTAL_PADDING = 5;
const DEFAULT_ARROW_SIZE = 20;
const DEFAULT_PLACEHOLDER = 'Please select...';
const DEFAULT_SEARCH_PLACEHOLDER = 'Search here...';
const DEFAULT_HEIGHT = 40;
const DEFAULT_WIDTH = 250;
const DEFAULT_CLOSED_COLOR = '#6c757d';
const DEFAULT_OPENED_COLOR = '#000';
const DEFAULT_ARROW_COLOR_SELECTED = '#000';
const DEFAULT_ARROW_COLOR_UNSELECTED = '#6c757d';
const DEFAULT_BG_COLOR = '#fff';
const Base = /*#__PURE__*/memo(props => {
  const {
    data,
    placeholder: mainPlaceHolder,
    width = DEFAULT_WIDTH,
    height = DEFAULT_HEIGHT,
    boxClosedBorderColor = DEFAULT_CLOSED_COLOR,
    boxOpenedBorderColor = DEFAULT_OPENED_COLOR,
    closeOnSelect = true,
    onSelect,
    placeHolderTextStyle = {},
    textStyle = {},
    arrowColorOnSelected = DEFAULT_ARROW_COLOR_SELECTED,
    arrowColor = DEFAULT_ARROW_COLOR_UNSELECTED,
    backgroundColor = DEFAULT_BG_COLOR,
    listBoxBackgroundColor,
    maxListHeight,
    listItemTextStyle,
    listItemSelectedTextStyle,
    listItemSelectedBackgroundColor,
    multiple = false,
    searchable = false,
    notFoundTextStyle = {},
    noDataText,
    defaultValues = []
  } = props;
  const placeholder = mainPlaceHolder || (searchable ? DEFAULT_SEARCH_PLACEHOLDER : DEFAULT_PLACEHOLDER);
  const [selected, setSelected] = useState(defaultValues);
  const [opened, setOpened] = useState(false);
  const [search, setSearch] = useState('');
  const [locationConfig, setLocationConfig] = useState({
    x: 0,
    y: 0
  });
  const ref = useRef(null);
  const handleClick = () => {
    var _ref$current;
    ref === null || ref === void 0 ? void 0 : (_ref$current = ref.current) === null || _ref$current === void 0 ? void 0 : _ref$current.measureInWindow((x, y) => {
      setLocationConfig({
        x,
        y
      });
    });
    setOpened(prev => !prev);
  };
  const handleSelect = value => {
    if (multiple) {
      setSelected(prev => {
        let temp = prev;
        const found = temp.findIndex(item => item === value);
        if (found !== -1) {
          temp = temp.filter(item => item !== value);
        } else {
          temp.push(value);
        }
        return [...temp];
      });
    } else {
      setSelected([value]);
      if (closeOnSelect) {
        setOpened(false);
      }
    }
    setSearch('');
  };
  useEffect(() => {
    if (typeof onSelect === 'function') {
      onSelect(selected);
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [selected]);
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: handleClick,
    ref: ref
  }, searchable ? /*#__PURE__*/React.createElement(SearchableBox, {
    data: data,
    placeholder: placeholder,
    width: width,
    height: height,
    boxClosedBorderColor: boxClosedBorderColor,
    boxOpenedBorderColor: boxOpenedBorderColor,
    placeHolderTextStyle: placeHolderTextStyle,
    textStyle: textStyle,
    arrowColorOnSelected: arrowColorOnSelected,
    arrowColor: arrowColor,
    backgroundColor: backgroundColor,
    arrowSize: DEFAULT_ARROW_SIZE,
    horizontalPadding: DEFAULT_HORIZONTAL_PADDING,
    opened: opened,
    selected: selected,
    handleChangeSearch: str => setSearch(str),
    search: search
  }) : /*#__PURE__*/React.createElement(ClickableBox, {
    data: data,
    placeholder: placeholder,
    width: width,
    height: height,
    boxClosedBorderColor: boxClosedBorderColor,
    boxOpenedBorderColor: boxOpenedBorderColor,
    placeHolderTextStyle: placeHolderTextStyle,
    textStyle: textStyle,
    arrowColorOnSelected: arrowColorOnSelected,
    arrowColor: arrowColor,
    backgroundColor: backgroundColor,
    arrowSize: DEFAULT_ARROW_SIZE,
    horizontalPadding: DEFAULT_HORIZONTAL_PADDING,
    opened: opened,
    selected: selected
  })), opened && /*#__PURE__*/React.createElement(List, {
    data: data,
    locationConfig: locationConfig,
    boxHeight: height,
    boxWidth: width,
    onSelect: handleSelect,
    selectedItemValues: selected,
    listBoxBackgroundColor: listBoxBackgroundColor,
    maxListHeight: maxListHeight,
    listItemTextStyle: listItemTextStyle,
    listItemSelectedTextStyle: listItemSelectedTextStyle,
    listItemSelectedBackgroundColor: listItemSelectedBackgroundColor,
    multiple: multiple,
    search: search,
    handleClose: () => setOpened(false),
    notFoundTextStyle: notFoundTextStyle,
    noDataText: noDataText
  }));
});
Base.displayName = 'Base';
export default Base;
//# sourceMappingURL=base.js.map